# Rules excluded for linting

D100 Missing docstring in public module

D101 Missing docstring in public class

D102 Missing docstring in public method

D103 Missing docstring in public function

D105 Missing docstring in magic method

D107 Missing docstring in `__init__`

D200 One-line docstring should fit on one line

D202 No blank lines allowed after function docstring

D203 1 blank line required before class docstring

D204 1 blank line required after class docstring

D205 1 blank line required between summary line and description

D208 Docstring is over-indented

D212 Multi-line docstring summary should start at the first line

D214 Section is over-indented

D215 Section underline is over-indented

D400 First line should end with a period

D401 First line of docstring should be in imperative mood

D404 First word of the docstring should not be "This"

D413 Missing blank line after last section

D415 First line should end with a period, question mark, or exclamation point

D417 Missing argument description

# Rules selected for fixing

W291 Trailing whitespace

W292 No newline at end of file

W293 Blank line contains whitespace
